@@ -17,7 +17,10 @@ from typing import List
 class Enigma:
     def __init__(self):
         """ENIGMA template"""
-        self.enigma_dir = root_dir / 'data' / 'enigmaDTI'
+        if 'enigma_data_dir' in os.environ:
+            self.enigma_dir = os.environ['enigma_data_dir']
+        else:
+            self.enigma_dir = root_dir / 'data' / 'enigmaDTI'
         self.template_fa_loc = self.enigma_dir / 'ENIGMA_DTI_FA.nii.gz'
         self.template_skeleton_loc = self.enigma_dir / \
             'ENIGMA_DTI_FA_skeleton_mask.nii.gz'
